@@ -1,4 +1,4 @@
-/* $Id: midgard.c 25718 2010-04-21 10:00:29Z piotras $
+/* $Id$
  *
  * Copyright (C) 2007, 2009 Piotr Pokora <piotrek.pokora@gmail.com>
  *
@@ -170,6 +170,9 @@ midgard_init()
 	type = MIDGARD_TYPE_METADATA;
 	g_assert (type != 0);
 	g_type_class_ref (type);
+	/* Initialize MidgardMetadataClass */
+	MidgardMetadata *m = g_object_new (MIDGARD_TYPE_METADATA, NULL);
+	g_object_unref (m);
 
 	/* Register transform function explicitly, we need own routine */
 	g_value_register_transform_func (G_TYPE_STRING, G_TYPE_FLOAT, __transform_string_to_float);
