@@ -19,11 +19,11 @@
 #include "midgard_collector.h"
 #include "midgard_object.h"
 #include "query_builder.h"
-#include "midgard_object_class.h"
 #include "midgard_core_query_builder.h"
 #include <libgda/libgda.h>
 #include "midgard_core_query.h"
 #include "midgard_core_object_class.h"
+#include "midgard_core_object.h"
 
 struct _MidgardCollectorPrivate{
 	const gchar *typename;
@@ -36,6 +36,7 @@ struct _MidgardCollectorPrivate{
 	MidgardObjectClass *klass;
 	GList *values;
 	GData *datalist;
+	MidgardConnection *mgd;
 };
 
 static const gchar *_collector_find_class_property(
@@ -50,7 +51,7 @@ static const gchar *_collector_find_class_property(
 	if(table_field == NULL) {
 		 
 		MidgardMetadataClass *mklass =
-			(MidgardMetadataClass*) g_type_class_peek(g_type_from_name("midgard_metadata"));
+			(MidgardMetadataClass*) g_type_class_peek(g_type_from_name("MidgardMetadata"));
 
 		table_field =
 			midgard_core_class_get_property_tablefield(
@@ -136,11 +137,11 @@ MidgardCollector *midgard_collector_new(
 			"=", value);
 
 	MidgardDBObjectClass *klass = MIDGARD_DBOBJECT_CLASS(self->priv->klass);
-	MidgardQueryConstraint *constraint = midgard_query_constraint_new();
-	midgard_query_constraint_set_builder(constraint, self->priv->builder);
-	midgard_query_constraint_set_class(constraint, klass);
+	MidgardCoreQueryConstraint *constraint = midgard_core_query_constraint_new();
+	midgard_core_query_constraint_set_builder(constraint, self->priv->builder);
+	midgard_core_query_constraint_set_class(constraint, klass);
 
-	if(!midgard_query_constraint_parse_property(&constraint, klass, domain)) {
+	if(!midgard_core_query_constraint_parse_property(&constraint, klass, domain)) {
 		
 		g_object_unref(constraint);
 		
@@ -164,6 +165,7 @@ MidgardCollector *midgard_collector_new(
 	self->priv->domain_value = value;
 	self->priv->keyname = NULL;
 	self->priv->keyname_value = NULL;
+	self->priv->mgd = mgd;
 	
 	g_value_unset(value);
 	g_free(value);
@@ -212,16 +214,25 @@ gboolean midgard_collector_set_key_property(
 	g_assert(self != NULL);
 
 	MidgardDBObjectClass *klass = MIDGARD_DBOBJECT_CLASS(g_type_class_peek(self->priv->builder->priv->type));
-	MidgardQueryConstraint *constraint = midgard_query_constraint_new();
-	midgard_query_constraint_set_builder(constraint, self->priv->builder);
-	midgard_query_constraint_set_class(constraint, klass);
+	MidgardCoreQueryConstraint *constraint = midgard_core_query_constraint_new();
+	midgard_core_query_constraint_set_builder(constraint, self->priv->builder);
+	midgard_core_query_constraint_set_class(constraint, klass);
 
-	if(!midgard_query_constraint_parse_property(&constraint, klass, key)) {
+	if(!midgard_core_query_constraint_parse_property(&constraint, klass, key)) {
 		
 		g_object_unref(constraint);
 		return FALSE;
 	}
+
+	/* Check if property is private */
+	MidgardDBObjectClass *dbklass = MIDGARD_DBOBJECT_CLASS (constraint->priv->klass);
+	MgdSchemaTypeAttr *type_attr = dbklass->dbpriv->storage_data;
+	if (midgard_core_object_property_refuse_private (self->priv->mgd, type_attr, NULL, constraint->priv->propname)) {
 	
+		g_object_unref(constraint);
+		return FALSE;
+	}
+
 	gchar *sql_field = g_strconcat(constraint->priv->current->table, ".",
 			constraint->priv->current->field, " AS midgard_collector_key", NULL);
 	
@@ -279,16 +290,25 @@ gboolean midgard_collector_add_value_property(
 	}
 	
 	MidgardDBObjectClass *klass = MIDGARD_DBOBJECT_CLASS(g_type_class_peek(self->priv->builder->priv->type));
-	MidgardQueryConstraint *constraint = midgard_query_constraint_new();
-	midgard_query_constraint_set_builder(constraint, self->priv->builder);
-	midgard_query_constraint_set_class(constraint, klass);
+	MidgardCoreQueryConstraint *constraint = midgard_core_query_constraint_new();
+	midgard_core_query_constraint_set_builder(constraint, self->priv->builder);
+	midgard_core_query_constraint_set_class(constraint, klass);
 
-	if(!midgard_query_constraint_parse_property(&constraint, klass, value)) {
+	if(!midgard_core_query_constraint_parse_property(&constraint, klass, value)) {
 		
 		g_object_unref(constraint);
 		return FALSE;
 	}
 	
+	/* Check if property is private */
+	MidgardDBObjectClass *dbklass = MIDGARD_DBOBJECT_CLASS (constraint->priv->klass);
+	MgdSchemaTypeAttr *type_attr = dbklass->dbpriv->storage_data;
+	if (midgard_core_object_property_refuse_private (self->priv->mgd, type_attr, NULL, constraint->priv->propname)) {
+	
+		g_object_unref(constraint);
+		return FALSE;
+	}
+
 	gchar *sql_field = g_strconcat(constraint->priv->current->table, ".",
 			constraint->priv->current->field, " AS ",
 			constraint->priv->pspec->name, NULL);
@@ -908,16 +928,19 @@ midgard_collector_execute (MidgardCollector *self)
 			}
 
 			midgard_collector_set(self,
-					g_value_dup_string((GValue*)ck_value),
+					g_value_get_string((GValue*)ck_value),
 					gda_data_model_get_column_title(model, columns),
 					new_value);
 			
 			if (ret_fields == 1){
 
 				midgard_collector_set(self,
-						g_value_dup_string((GValue*)ck_value),
+						g_value_get_string((GValue*)ck_value),
 						NULL,
 						NULL);
+
+				g_value_unset (new_value);
+				g_free (new_value);
 			}
 
 			g_value_unset(ck_value);
@@ -1018,9 +1041,7 @@ GType midgard_collector_get_type(void)
 			0,              /* n_preallocs */
 			(GInstanceInitFunc) _midgard_collector_instance_init /* instance_init */
 		};	
-		type = g_type_register_static (MIDGARD_TYPE_QUERY_BUILDER,
-				"midgard_collector",
-				&info, 0);
+		type = g_type_register_static (MIDGARD_TYPE_QUERY_BUILDER, "MidgardCollector", &info, 0);
 	}
 	return type;
 }
