@@ -69,7 +69,7 @@ static void __get_property_attribute (xmlNode *node, gchar **property_string,
 		}
 
 		*target_name = property_string[2];
-		*prop_attr = g_hash_table_lookup (MIDGARD_DBOBJECT_CLASS (klass)->dbpriv->storage_data->prophash, *target_name);
+		*prop_attr = g_hash_table_lookup (MIDGARD_DBOBJECT_CLASS (MGD_DBCLASS_METADATA_CLASS (klass))->dbpriv->storage_data->prophash, *target_name);
 	
 		if (!*prop_attr)
 			__view_error (node, "%s not found. Not registered for %s.metadata ?", *target_name, property_string[0]);
@@ -430,6 +430,9 @@ gchar *__build_static_create_view(MgdSchemaTypeAttr *type)
 	guint i = 0;
 	g_string_append(query, " WHERE ");
 
+	if (!type->joins)
+		g_string_append_printf (query, " %s.metadata_deleted = 0 ", type->table);
+
 	for (list = type->joins; list != NULL; list = list->next) {
 		
 		if(i > 0)
@@ -492,14 +495,23 @@ static void __register_view_type (MgdSchemaTypeAttr *type)
 		g_free(type->sql_select_full);
 		guint i;
 		GString *ssf = g_string_new("");
+		gboolean add_coma = FALSE;
 
 		for (i = 0; i < type->class_nprop; i++) {
-			
-			if (i == 0)
+		
+			if (G_TYPE_FUNDAMENTAL (pspecs[i]->value_type) == G_TYPE_OBJECT) {
+				if (i == 1)
+					add_coma = FALSE;
+				continue;
+			}
+
+			if (!add_coma)
 				g_string_append(ssf, pspecs[i]->name);
 			else 
 				g_string_append_printf(ssf, ", %s", pspecs[i]->name);
 
+			add_coma = TRUE;
+
 			/* Replace tablefield for every property */
 			MgdSchemaPropertyAttr *prop_attr = g_hash_table_lookup(type->prophash, pspecs[i]->name);
 			if (!prop_attr) {
