@@ -44,7 +44,7 @@ static MidgardCollector *__create_domain_collector(MidgardConnection *mgd, const
 	return mc;
 }
 
-static MidgardCollector *__get_parameters_collector(MgdObject *object, 
+static MidgardCollector *__get_parameters_collector(MidgardObject *object, 
 		const gchar *domain)
 {	
 	if(!object->priv->_params) {
@@ -57,35 +57,35 @@ static MidgardCollector *__get_parameters_collector(MgdObject *object,
 }
 
 static void __register_domain_collector(
-		MgdObject *object, const gchar *domain, MidgardCollector *mc)
+		MidgardObject *object, const gchar *domain, MidgardCollector *mc)
 {		
 	if(object->priv->_params)
 		g_hash_table_insert(object->priv->_params, (gpointer) g_strdup(domain), mc);
 }
 
-static gboolean __is_guid_valid(MgdObject *self)
+static gboolean __is_guid_valid(MidgardObject *self)
 {
-	if(self->dbpriv->guid == NULL) {
+	if(MGD_OBJECT_GUID (self) == NULL) {
 
-		midgard_set_error(self->dbpriv->mgd,
+		midgard_set_error(MGD_OBJECT_CNC (self),
 				MGD_GENERIC_ERROR,
 				MGD_ERR_INVALID_PROPERTY_VALUE,
 				" Guid property is NULL for %s. ", 
 				G_OBJECT_TYPE_NAME(self));
-		g_warning("%s", self->dbpriv->mgd->err->message); 
-		g_clear_error(&self->dbpriv->mgd->err);
+		g_warning("%s", MGD_OBJECT_CNC (self)->err->message); 
+		g_clear_error(&MGD_OBJECT_CNC (self)->err);
 		return FALSE;
 	}
 
-	if(!midgard_is_guid(self->dbpriv->guid)) {
+	if(!midgard_is_guid(MGD_OBJECT_GUID (self))) {
 
-		midgard_set_error(self->dbpriv->mgd,
+		midgard_set_error(MGD_OBJECT_CNC (self),
 				MGD_GENERIC_ERROR,
 				MGD_ERR_INVALID_PROPERTY_VALUE,
 				" Guid-property of %s has invalid value.", 
 				G_OBJECT_TYPE_NAME(self));
-		g_warning("%s", self->dbpriv->mgd->err->message);
-		g_clear_error(&self->dbpriv->mgd->err);
+		g_warning("%s", MGD_OBJECT_CNC (self)->err->message);
+		g_clear_error(&MGD_OBJECT_CNC (self)->err);
 		return FALSE;
 	}
 
@@ -94,7 +94,7 @@ static gboolean __is_guid_valid(MgdObject *self)
 
 /**
  * midgard_object_get_paramater:
- * @self: #MgdObject instance
+ * @self: #MidgardObject instance
  * @domain: parameter's domain string
  * @name: parameter's name string
  *
@@ -103,7 +103,7 @@ static gboolean __is_guid_valid(MgdObject *self)
  *
  * Returns: GValue which holds value for domain&name pair
  */
-const GValue *midgard_object_get_parameter(MgdObject *self,
+const GValue *midgard_object_get_parameter(MidgardObject *self,
 		const gchar *domain, const gchar *name)
 {
 	g_assert(self);
@@ -118,12 +118,12 @@ const GValue *midgard_object_get_parameter(MgdObject *self,
 	if(domain_collector == NULL){
 		
 		MidgardCollector *mc = 
-			__create_domain_collector(self->dbpriv->mgd, domain);
+			__create_domain_collector(MGD_OBJECT_CNC (self), domain);
 
 		/* Limit records to these with parent guid */
 		GValue guid_value = {0, };
 		g_value_init(&guid_value, G_TYPE_STRING);
-		g_value_set_string(&guid_value, self->dbpriv->guid);
+		g_value_set_string(&guid_value, MGD_OBJECT_GUID (self));
 	
 		midgard_collector_add_constraint(mc,
 				"parentguid", "=", &guid_value);
@@ -132,7 +132,7 @@ const GValue *midgard_object_get_parameter(MgdObject *self,
 		midgard_collector_execute(mc);
 		
 		/* prepend collector to object's parameter list 
-		 * we will free it in MgdObject destructor */
+		 * we will free it in MidgardObject destructor */
 		self->priv->parameters = 
 			g_slist_prepend(self->priv->parameters, mc);
 
@@ -156,7 +156,7 @@ const GValue *midgard_object_get_parameter(MgdObject *self,
 
 /**
  * midgard_object_set_parameter:
- * @self: #MgdObject instance
+ * @self: #MidgardObject instance
  * @domain: parameter's domain string
  * @name: parameter's name string
  * @value: a GValue value which should be set for domain&name pair
@@ -166,14 +166,14 @@ const GValue *midgard_object_get_parameter(MgdObject *self,
  * Returns: %TRUE on success, %FALSE otherwise
  */ 
 gboolean 
-midgard_object_set_parameter (MgdObject *self, const gchar *domain, const gchar *name, GValue *value) 
+midgard_object_set_parameter (MidgardObject *self, const gchar *domain, const gchar *name, GValue *value) 
 {
 	g_return_val_if_fail (self != NULL, FALSE);
 
 	if(!__is_guid_valid(self))
 		return FALSE;
 		
-	MgdObject *param;
+	MidgardObject *param;
 	const gchar *value_string =
 		g_value_get_string(value);
 	gboolean delete_parameter = FALSE;
@@ -191,25 +191,25 @@ midgard_object_set_parameter (MgdObject *self, const gchar *domain, const gchar
 
 	if(!domain_collector) {
 
-		domain_collector = __create_domain_collector(self->dbpriv->mgd, domain);
+		domain_collector = __create_domain_collector(MGD_OBJECT_CNC (self), domain);
 		__register_domain_collector(self, domain, domain_collector);
 	}
 
 	/* This is the case when set_parameter is invoked
 	 * before any get_parameter */
 	if(get_value == NULL && delete_parameter) {
-		MIDGARD_ERRNO_SET(self->dbpriv->mgd, MGD_ERR_NOT_EXISTS);
+		MIDGARD_ERRNO_SET(MGD_OBJECT_CNC (self), MGD_ERR_NOT_EXISTS);
 		return FALSE;
 	}
 
 	/* Parameter doesn't exist. We have to create it */
 	if(get_value == NULL && !delete_parameter){
 		
-		param = midgard_object_new(self->dbpriv->mgd, "midgard_parameter", NULL);
+		param = midgard_object_new(MGD_OBJECT_CNC (self), "midgard_parameter", NULL);
 		g_object_set(param, 
 				"domain", domain, 
 				"name", name,
-				"parentguid", self->dbpriv->guid,
+				"parentguid", MGD_OBJECT_GUID (self),
 				NULL);
 			
 		g_object_set_property(G_OBJECT(param), "value", value);
@@ -238,11 +238,11 @@ midgard_object_set_parameter (MgdObject *self, const gchar *domain, const gchar
 	} else {
 		
 		MidgardQueryBuilder *builder = 
-			midgard_query_builder_new(self->dbpriv->mgd,
+			midgard_query_builder_new(MGD_OBJECT_CNC (self),
 					"midgard_parameter");
 		GValue gval = {0,};
 		g_value_init(&gval, G_TYPE_STRING);
-		g_value_set_string(&gval, self->dbpriv->guid);
+		g_value_set_string(&gval, MGD_OBJECT_GUID (self));
 		midgard_query_builder_add_constraint(builder,
 				"parentguid", "=", &gval);
 		g_value_unset(&gval);
@@ -271,7 +271,7 @@ midgard_object_set_parameter (MgdObject *self, const gchar *domain, const gchar
 		if(delete_parameter){
 
 			if(midgard_object_delete(
-						MIDGARD_OBJECT(ret_object[0]))) {
+						MIDGARD_OBJECT(ret_object[0]), FALSE)) {
 				midgard_collector_remove_key(
 						domain_collector,
 						name);
@@ -305,7 +305,7 @@ midgard_object_set_parameter (MgdObject *self, const gchar *domain, const gchar
 
 /**
  * midgard_object_list_parameters: 
- * @self: a #MgdObject self instance
+ * @self: a #MidgardObject self instance
  * @domain: optional paramaters' domain
  * 
  * Returned objects are midgard_parameter class. Parameter objects are 
@@ -316,18 +316,18 @@ midgard_object_set_parameter (MgdObject *self, const gchar *domain, const gchar
  * 
  * Returns: Newly allocated and NULL terminated array of midgard_parameter objects. 
  */
-MgdObject **midgard_object_list_parameters(MgdObject *self, const gchar *domain)
+MidgardObject **midgard_object_list_parameters(MidgardObject *self, const gchar *domain)
 {
 	g_return_val_if_fail(self != NULL, NULL);
-	g_return_val_if_fail(self->dbpriv->guid != NULL, NULL);
-	g_return_val_if_fail(self->dbpriv->mgd != NULL, NULL);
+	g_return_val_if_fail(MGD_OBJECT_GUID (self) != NULL, NULL);
+	g_return_val_if_fail(MGD_OBJECT_CNC (self) != NULL, NULL);
 
-	MgdObject **objects = NULL;
+	MidgardObject **objects = NULL;
 
 	if(domain == NULL) {
 
 		objects = midgard_core_object_parameters_list(
-				self->dbpriv->mgd, "midgard_parameter", self->dbpriv->guid);
+				MGD_OBJECT_CNC (self), "midgard_parameter", MGD_OBJECT_GUID (self));
 		
 		return objects;
 	}
@@ -341,8 +341,8 @@ MgdObject **midgard_object_list_parameters(MgdObject *self, const gchar *domain)
 	parameters[0].value = dval;
 
 	objects = midgard_core_object_parameters_find(
-			self->dbpriv->mgd, "midgard_parameter", 
-			self->dbpriv->guid, 1, (const GParameter*) parameters);
+			MGD_OBJECT_CNC (self), "midgard_parameter", 
+			MGD_OBJECT_GUID (self), 1, (const GParameter*) parameters);
 
 	g_value_unset(&dval);
 	g_free(parameters);
@@ -352,7 +352,7 @@ MgdObject **midgard_object_list_parameters(MgdObject *self, const gchar *domain)
 
 /**
  * midgard_object_delete_parameters:
- * @self: #MgdObject instance
+ * @self: #MidgardObject instance
  * @n_params: number of properties
  * @parameters: properties list
  *
@@ -362,24 +362,24 @@ MgdObject **midgard_object_list_parameters(MgdObject *self, const gchar *domain)
  *
  * Returns: %TRUE on success, %FALSE if at least one of the parameters could not be deleted
  */
-gboolean midgard_object_delete_parameters(MgdObject *self, 
+gboolean midgard_object_delete_parameters(MidgardObject *self, 
 		guint n_params, const GParameter *parameters)
 {
 	g_assert(self != NULL);
 
-	if(!self->dbpriv->guid) {
+	if(!MGD_OBJECT_GUID (self)) {
 		
 		g_warning("Object is not fetched from database. Empty guid");
 	}
 
 	return midgard_core_object_parameters_delete(
-			self->dbpriv->mgd, "midgard_parameter", 
-			self->dbpriv->guid, n_params, parameters);
+			MGD_OBJECT_CNC (self), "midgard_parameter", 
+			MGD_OBJECT_GUID (self), n_params, parameters);
 }
 
 /**
  * midgard_object_purge_parameters:
- * @self: #MgdObject instance
+ * @self: #MidgardObject instance
  * @n_params: number of properties
  * @parameters: properties list
  *
@@ -389,24 +389,24 @@ gboolean midgard_object_delete_parameters(MgdObject *self,
  *
  * Returns: %TRUE on success, %FALSE if at least one of the parameters could not be purged
  */
-gboolean midgard_object_purge_parameters(MgdObject *self, 
+gboolean midgard_object_purge_parameters(MidgardObject *self, 
 		guint n_params, const GParameter *parameters)
 {
 	g_assert(self != NULL);
 
-	if(!self->dbpriv->guid) {
+	if(!MGD_OBJECT_GUID (self)) {
 		
 		g_warning("Object is not fetched from database. Empty guid");
 	}
 
 	return midgard_core_object_parameters_purge(
-			self->dbpriv->mgd, "midgard_parameter", 
-			self->dbpriv->guid, n_params, parameters);
+			MGD_OBJECT_CNC (self), "midgard_parameter", 
+			MGD_OBJECT_GUID (self), n_params, parameters);
 }
 
 /**
  * midgard_object_find_parameters:
- * @self: #MgdObject instance
+ * @self: #MidgardObject instance
  * @n_params: number of properties
  * @parameters: properties list
  *
@@ -414,30 +414,30 @@ gboolean midgard_object_purge_parameters(MgdObject *self,
  * @parameters argument is optional. All object's parameters are 
  * returned ( if exist ) if @parameters is explicitly set to %NULL.
 *
- * Returns: newly created, NULL terminated array of #MgdObject ( midgard_parameter class ) or %NULL on failure
+ * Returns: newly created, NULL terminated array of #MidgardObject ( midgard_parameter class ) or %NULL on failure
  */
-MgdObject **midgard_object_find_parameters(MgdObject *self, 
+MidgardObject **midgard_object_find_parameters(MidgardObject *self, 
 		guint n_params, const GParameter *parameters)
 {
 	g_assert(self != NULL);
 
-	if(!self->dbpriv->guid) {
+	if(!MGD_OBJECT_GUID (self)) {
 		
 		g_warning("Object is not fetched from database. Empty guid");
 	}
 
 	return midgard_core_object_parameters_find(
-			self->dbpriv->mgd, "midgard_parameter", 
-			self->dbpriv->guid, n_params, parameters);
+			MGD_OBJECT_CNC (self), "midgard_parameter", 
+			MGD_OBJECT_GUID (self), n_params, parameters);
 }
 
 /**
  * midgard_object_has_parameters:
- * @self: #MgdObject instance
+ * @self: #MidgardObject instance
  *
  * Returns: %TRUE if object has paramateres, %FALSE otherwise.
  */ 
-gboolean midgard_object_has_parameters(MgdObject *self)
+gboolean midgard_object_has_parameters(MidgardObject *self)
 {
 	g_assert(self != NULL);
 
@@ -447,7 +447,7 @@ gboolean midgard_object_has_parameters(MgdObject *self)
 
 /* Internal routines */
 
-MgdObject **midgard_core_object_parameters_list(
+MidgardObject **midgard_core_object_parameters_list(
 		MidgardConnection *mgd, const gchar *class_name, const gchar *guid)
 {
 	g_assert(class_name != NULL);
@@ -472,10 +472,10 @@ MgdObject **midgard_core_object_parameters_list(
 
 	g_object_unref(builder);
 
-	return (MgdObject **)objects;
+	return (MidgardObject **)objects;
 }
 
-MgdObject *midgard_core_object_parameters_create(
+MidgardObject *midgard_core_object_parameters_create(
 		MidgardConnection *mgd, const gchar *class_name,
 		const gchar *guid, guint n_params, const GParameter *parameters)
 {
@@ -492,7 +492,7 @@ MgdObject *midgard_core_object_parameters_create(
 	MidgardObjectClass *klass = 
 		MIDGARD_OBJECT_GET_CLASS_BY_NAME(class_name);
 
-	MgdObject *object = midgard_object_new(mgd, class_name, NULL);
+	MidgardObject *object = midgard_object_new(mgd, class_name, NULL);
 
 	/* Check if properties in parameters are registered for given class */
 	for ( i = 0; i < n_params; i++) {
@@ -596,7 +596,7 @@ gboolean midgard_core_object_parameters_delete(
 	
 	while (objects[i] != NULL ) {
 	
-		if(midgard_object_delete(MIDGARD_OBJECT(objects[i])))
+		if(midgard_object_delete(MIDGARD_OBJECT(objects[i]), FALSE))
 			rv = TRUE;
 
 		g_object_unref(objects[i]);
@@ -627,7 +627,7 @@ gboolean midgard_core_object_parameters_purge(
 	
 	while (objects[i] != NULL ) {
 	
-		if(midgard_object_purge(MIDGARD_OBJECT(objects[i])))
+		if(midgard_object_purge(MIDGARD_OBJECT(objects[i]), FALSE))
 			rv = TRUE;
 
 		g_object_unref(objects[i]);
@@ -675,7 +675,7 @@ gboolean midgard_core_object_parameters_purge_with_blob(
 		if(midgard_blob_exists(blob))
 			midgard_blob_remove_file(blob);
 		
-		midgard_object_purge(MIDGARD_OBJECT(objects[i]));
+		midgard_object_purge(MIDGARD_OBJECT(objects[i]), FALSE);
 
 		g_object_unref(blob);
 		g_object_unref(objects[i]);
@@ -716,7 +716,7 @@ MidgardQueryBuilder *midgard_core_object_parameter_query_builder(
 	return builder;
 }
 
-MgdObject **midgard_core_object_parameters_find(
+MidgardObject **midgard_core_object_parameters_find(
 		MidgardConnection *mgd, const gchar *class_name,
 		const gchar *guid, guint n_params, const GParameter *parameters)
 {
@@ -761,7 +761,7 @@ MgdObject **midgard_core_object_parameters_find(
 	GObject **objects = midgard_query_builder_execute(builder, &n_objects);
 	g_object_unref(builder);
 
-	return (MgdObject **)objects;
+	return (MidgardObject **)objects;
 }
 
 gboolean midgard_core_object_has_parameters(
