@@ -24,10 +24,10 @@
 #include "midgard_blob.h"
 #include "midgard_timestamp.h"
 #include "midgard_error.h"
-#include "midgard_object_class.h"
 #include "midgard_user.h"
 #include "midgard_core_query.h"
 #include "guid.h"
+#include "midgard_schema_object_factory.h"
 
 #define __mr_dbus_send(_obj, _action) \
 	gchar *_dbus_path = g_strconcat("/replication/", \
@@ -163,7 +163,7 @@ midgard_replicator_export_by_guid (MidgardConnection *mgd, const gchar *guid)
 
 	const gchar *table = 
 		midgard_core_class_get_table(MIDGARD_DBOBJECT_CLASS(klass)); 
-	GValue *tval = NULL;
+	GValue tval = {0, };
 	gchar *timeupdated;
 	gint qr;
 
@@ -180,8 +180,9 @@ midgard_replicator_export_by_guid (MidgardConnection *mgd, const gchar *guid)
 					"%s SET ",
 					table);
 
-			tval = midgard_timestamp_new_current();
-			timeupdated = midgard_timestamp_get_string(tval);
+
+			midgard_timestamp_new_current (&tval);
+			timeupdated = midgard_timestamp_get_string_from_value (&tval);
 			
 			g_string_append_printf(sql, "metadata_exported='%s' WHERE guid = '%s' ", 
 					timeupdated, guid);
@@ -189,7 +190,7 @@ midgard_replicator_export_by_guid (MidgardConnection *mgd, const gchar *guid)
 			qr = midgard_core_query_execute(mgd, sql->str, TRUE);
 			g_string_free(sql, TRUE);
 
-			g_value_unset(tval);
+			g_value_unset (&tval);
 			g_free(timeupdated);
 
 			if (qr == 0) {
@@ -208,7 +209,7 @@ midgard_replicator_export_by_guid (MidgardConnection *mgd, const gchar *guid)
 /**
  * midgard_replicator_export_purged:
  * @mgd: #MidgardConnection instance
- * @klass: #MidgardObjectClass pointer
+ * @classname: name of #MidgardObjectClass derived one
  * @startdate: optional start date 
  * @enddate: optional end date
  *
@@ -218,9 +219,12 @@ midgard_replicator_export_by_guid (MidgardConnection *mgd, const gchar *guid)
  * Returns: xml buffer with serialized objects or %NULL if there are no objects matching given criteria.
  */ 
 gchar *
-midgard_replicator_export_purged (MidgardConnection *mgd, MidgardObjectClass *klass, const gchar *startdate, const gchar *enddate)
+midgard_replicator_export_purged (MidgardConnection *mgd, const gchar *classname, const gchar *startdate, const gchar *enddate)
 {
 	g_return_val_if_fail (mgd != NULL, NULL);
+	g_return_val_if_fail (classname != NULL, NULL);
+
+	MidgardDBObjectClass *klass = g_type_class_peek (g_type_from_name (classname));
 	g_return_val_if_fail (klass != NULL, NULL);
 
 	MIDGARD_ERRNO_SET(mgd, MGD_ERR_OK);
@@ -314,10 +318,10 @@ midgard_replicator_export_purged (MidgardConnection *mgd, MidgardObjectClass *kl
  * Returns: Newly allocated xml buffer, which holds blob data base64 encoded, or %NULL.
  */    
 gchar *
-midgard_replicator_serialize_blob (MgdObject *object)
+midgard_replicator_serialize_blob (MidgardObject *object)
 {	
 	GType attachment_type = g_type_from_name ("midgard_attachment");
-	g_return_val_if_fail (G_OBJECT_TYPE (object) != attachment_type, NULL);
+	g_return_val_if_fail (G_OBJECT_TYPE (object) == attachment_type, NULL);
 
 	MidgardBlob *blob = midgard_blob_new(object, NULL);
 
@@ -346,7 +350,7 @@ midgard_replicator_serialize_blob (MgdObject *object)
 				"midgard_blob",
 				BAD_CAST encoded);
 	xmlNewProp(blob_node, BAD_CAST "guid",
-			BAD_CAST object->dbpriv->guid);
+			BAD_CAST MGD_OBJECT_GUID (object));
 
 	g_free(encoded);
 
@@ -364,9 +368,11 @@ midgard_replicator_serialize_blob (MgdObject *object)
  * @object: #MidgardObject of MIDGARD_TYPE_ATTACHMENT type
  *
  * Alias for midgard_replicator_serialize_blob().
+ *
+ * Returns: serialized object as xml data
  */ 
 gchar *
-midgard_replicator_export_blob(MgdObject *object)
+midgard_replicator_export_blob(MidgardObject *object)
 {
 	return midgard_replicator_serialize_blob(object);
 }
@@ -454,11 +460,11 @@ midgard_replicator_import_object (MidgardDBObject *object, gboolean force)
 	midgard_query_builder_include_deleted (builder);
 
 	guint n_objects;
-	GObject **_dbobject = midgard_query_builder_execute (builder, &n_objects);
-	MgdObject *dbobject;
-
-	if (!_dbobject){
+	GObject **_dbobjects = midgard_query_builder_execute (builder, &n_objects);
+	MidgardObject *dbobject;
 
+	if (!_dbobjects){
+	
 		g_object_unref (G_OBJECT (builder));
 		
 		if ((mgd->errnum == MGD_ERR_OBJECT_PURGED) && force) {
@@ -489,24 +495,53 @@ midgard_replicator_import_object (MidgardDBObject *object, gboolean force)
 	} else {
 
 		gchar *updated, *dbupdated;
-		dbobject = (MgdObject *)_dbobject[0];
+		dbobject = (MidgardObject *)_dbobjects[0];
+		g_free (_dbobjects);
+
 		GValue updated_timestamp = {0, };
 		g_value_init (&updated_timestamp, MGD_TYPE_TIMESTAMP);
 		GValue dbupdated_timestamp = {0, };
 		g_value_init (&dbupdated_timestamp, MGD_TYPE_TIMESTAMP);
+		
+		MidgardMetadata *metadata = MGD_DBOBJECT_METADATA (object);
 
 		/* Compare revised datetimes. We must know if imported 
 		 * object is newer than that one which exists in database */
-		g_object_get_property (G_OBJECT (MIDGARD_OBJECT (object)->metadata), "revised", &updated_timestamp);
-		g_object_get_property (G_OBJECT (MIDGARD_OBJECT (dbobject)->metadata), "revised", &dbupdated_timestamp);
+		g_object_get_property (G_OBJECT (metadata), "revised", &updated_timestamp);
+		g_object_get_property (G_OBJECT (metadata), "revised", &dbupdated_timestamp);
 
-		updated = midgard_timestamp_get_string ((const GValue *)&updated_timestamp);
-		dbupdated = midgard_timestamp_get_string ((const GValue *)&dbupdated_timestamp);
+		updated = midgard_timestamp_get_string_from_value ((const GValue *)&updated_timestamp);
+		dbupdated = midgard_timestamp_get_string_from_value ((const GValue *)&dbupdated_timestamp);
 
 		/* We can use g_ascii_strcasecmp as it type cast every single 
 		 * pointer to integer and unsigned char returning substract result */		
 		gint datecmp;
-		
+	
+	     	if (updated == NULL) {
+
+			g_warning ("Trying to import ivalid object. metadata.revised property holds NULL (Object: %s)", 
+					MGD_OBJECT_GUID (object));
+
+			if (dbupdated)
+				g_free (dbupdated);
+
+			g_object_unref (dbobject);
+
+			return FALSE;
+		}
+
+		if (dbupdated == NULL) {
+
+			g_warning ("Trying to import object for invalid object stored in database. metadata.revised property holds NULL (Database object:%s)", MGD_OBJECT_GUID (object));
+
+			if (updated)
+				g_free (updated);
+
+			g_object_unref (dbobject);
+
+			return FALSE;
+		}
+
 		if (force) {
 
 			datecmp = -1;
@@ -524,8 +559,7 @@ midgard_replicator_import_object (MidgardDBObject *object, gboolean force)
 
 		if (datecmp > 0 || datecmp == 0) {
 			
-			/* Database object is more recent or exactly the same */
-			g_object_unref (builder);
+			/* Database object is more recent or exactly the same */	
 			g_object_unref (dbobject);	
 			MIDGARD_ERRNO_SET (mgd, MGD_ERR_OBJECT_IMPORTED);
 	
@@ -536,28 +570,28 @@ midgard_replicator_import_object (MidgardDBObject *object, gboolean force)
 			/* Database object is elder */	
 			
 			/* DELETE */
-			g_object_get (G_OBJECT (MIDGARD_OBJECT (object)->metadata), "deleted", &deleted, NULL);
+			g_object_get (G_OBJECT (metadata), "deleted", &deleted, NULL);
 			/* Imported object is marked as deleted , so 
 			 * * we delete object from database */
 			if (deleted) {
 
-				g_object_unref (builder);
-				ret = midgard_object_delete (dbobject);
+				ret = midgard_object_delete (dbobject, FALSE);
 				g_object_unref (dbobject);
 				return ret;
 			}
 
 			/* UPDATE */
 		
+			MidgardMetadata *db_metadata = MGD_DBOBJECT_METADATA (dbobject);
+
 			/* Check if dbobject is deleted */
-			g_object_get (G_OBJECT (dbobject->metadata), "deleted", &deleted, NULL);
+			g_object_get (db_metadata, "deleted", &deleted, NULL);
 
 			guint undelete;
-			g_object_get (G_OBJECT (MIDGARD_OBJECT (object)->metadata), "deleted", &undelete, NULL);
+			g_object_get (G_OBJECT (metadata), "deleted", &undelete, NULL);
 
 			if ((deleted && !undelete)) {
-
-				midgard_object_undelete (mgd, MGD_OBJECT_GUID (dbobject));
+				midgard_schema_object_factory_object_undelete (mgd, MGD_OBJECT_GUID (dbobject));
 				goto _update_object;
 			}
 
@@ -569,8 +603,6 @@ midgard_replicator_import_object (MidgardDBObject *object, gboolean force)
 			}
 
 			_update_object:
-			g_object_unref(builder);
-
 			ret = _midgard_object_update (MIDGARD_OBJECT (object), OBJECT_UPDATE_IMPORTED);
 			g_object_unref (dbobject);
 			return ret;
@@ -605,7 +637,7 @@ static gboolean __import_blob_from_xml(	MidgardConnection *mgd,
 		return FALSE;
 	}
 
-	MgdObject *object = midgard_object_class_get_object_by_guid(mgd, guid);
+	MidgardObject *object = midgard_schema_object_factory_get_object_by_guid (mgd, guid);
 
 	/* TODO , Add more error messages to inform about object state. 
 	 * One is already set by midgard_object_class_get_object_by_guid */
@@ -616,7 +648,7 @@ static gboolean __import_blob_from_xml(	MidgardConnection *mgd,
 	}
 
 	/* FIXME, define even macro to get blobdir ( core level only ) */
-	gchar *blobdir = object->dbpriv->mgd->priv->config->blobdir;
+	gchar *blobdir = MIDGARD_DBOBJECT (object)->dbpriv->mgd->priv->config->blobdir;
 
 	if (!blobdir || (*blobdir != '/')
 			|| (stat(blobdir, &statbuf) != 0)
@@ -702,7 +734,7 @@ midgard_replicator_import_from_xml (MidgardConnection *mgd,  const gchar *xml, g
 	}
 
 	xmlChar *attr, *guid_attr;
-	MgdObject *dbobject;
+	MidgardObject *dbobject;
 
 	for(; child; child = _get_type_node(child->next)) {
 		
@@ -711,15 +743,14 @@ midgard_replicator_import_from_xml (MidgardConnection *mgd,  const gchar *xml, g
 
 		if(g_str_equal(attr, "yes")) {
 			
-			dbobject = midgard_object_class_get_object_by_guid(
-					mgd, (const gchar *)guid_attr);
+			dbobject = midgard_schema_object_factory_get_object_by_guid (mgd, (const gchar *)guid_attr);
 
 			if(dbobject || 
 					( !dbobject && 
 					 (mgd->errnum == MGD_ERR_OBJECT_DELETED)
 					 )) {
 		
-				midgard_object_purge(dbobject);
+				midgard_object_purge(dbobject, FALSE);
 				if(dbobject)
 					g_object_unref(dbobject);
 				xmlFree(attr);
@@ -730,7 +761,7 @@ midgard_replicator_import_from_xml (MidgardConnection *mgd,  const gchar *xml, g
 
 		xmlFree(attr);
 
-		MgdObject *object =
+		MidgardObject *object =
 			midgard_object_new(mgd, (const gchar *)child->name, NULL);
 		if(!object) {
 			g_warning("Can not create %s instance", child->name);
@@ -741,7 +772,7 @@ midgard_replicator_import_from_xml (MidgardConnection *mgd,  const gchar *xml, g
 		}
 
 		if (guid_attr) {
-			object->dbpriv->guid = (const gchar *)g_strdup((gchar *)guid_attr);
+			MGD_OBJECT_GUID (object) = (const gchar *)g_strdup((gchar *)guid_attr);
 		}
 
 		if(!_nodes2object(G_OBJECT(object), child->children, force)) {
@@ -791,7 +822,7 @@ GType midgard_replicator_get_type(void)
 			0,              /* n_preallocs */
 			NULL /* instance_init */
 		};
-		type = g_type_register_static (G_TYPE_OBJECT, "midgard_replicator", &info, 0);
+		type = g_type_register_static (G_TYPE_OBJECT, "MidgardReplicator", &info, 0);
 	}
 
 	return type;
