@@ -152,6 +152,21 @@ MidgardQueryBuilder *midgard_query_builder_new(
         }
 }
 
+/**
+ * midgard_query_builder_create_builder:
+ *
+ * Static constructor. Invokes midgard_query_builder_new().
+ * This function is added for language bindings, in which, that function
+ * can not be invoked explicitly.
+ *
+ * Since: 10.05.1
+ */
+MidgardQueryBuilder *
+midgard_query_builder_create_builder (MidgardConnection *mgd, const gchar *classname)
+{
+	return midgard_query_builder_new (mgd, classname);
+}
+
 void midgard_query_builder_free(MidgardQueryBuilder *builder) 
 {
 	g_assert(builder != NULL);
@@ -1023,11 +1038,11 @@ midgard_core_qb_set_object_from_query (MidgardQueryBuilder *builder, guint selec
 	for (rows = 0; rows < ret_rows; rows++) {
 	
 		if(!nobject)
-			object = g_object_new(builder->priv->type, NULL);
+			object = g_object_new (builder->priv->type, "connection", mgd, NULL);
 		else 
 			object = *nobject;
 
-		MIDGARD_DBOBJECT(object)->dbpriv->mgd = builder->priv->mgd;
+		MGD_OBJECT_IN_STORAGE (object) = TRUE;	
 				
 		if(dbklass->dbpriv->__set_from_sql != NULL) {
 			
@@ -1038,18 +1053,11 @@ midgard_core_qb_set_object_from_query (MidgardQueryBuilder *builder, guint selec
 		
 			/* Compute number of metadata properties */
 			guint n_md_props = 0;
+			MidgardMetadata *mklass = (MidgardMetadata *)MGD_DBCLASS_METADATA_CLASS (dbklass);
+			if (mklass) 
+				n_md_props = g_hash_table_size (MGD_DBCLASS_STORAGE_DATA (mklass)->prophash);
 
-			if (dbklass->dbpriv->has_metadata) {
-
-				/* FIXME, provide metadata class pointer member for MidgardDBObjectClass */
-				const gchar *metadata_classname = 
-					midgard_reflector_object_get_metadata_class (G_OBJECT_CLASS_NAME (dbklass));
-				GObjectClass *metadata_class = g_type_class_peek (g_type_from_name (metadata_classname));
-				GParamSpec **pspec = g_object_class_list_properties (metadata_class, &n_md_props);
-				g_free (pspec);
-			}
-
-			guint __cols = n_md_props + 1; /* Add guid column */
+			guint __cols = n_md_props + 1; /* Add one for guid */
 
 			/* we have guid and metadata columns first */
 			for (columns = __cols; columns < ret_fields; columns++) {	
@@ -1059,7 +1067,7 @@ midgard_core_qb_set_object_from_query (MidgardQueryBuilder *builder, guint selec
 					gda_data_model_get_column_title(model, columns);
 				GParamSpec *pspec =
 					g_object_class_find_property(G_OBJECT_GET_CLASS(object), coltitle);
-				
+
 				if(G_IS_VALUE(gvalue)) {
 
 					if (!pspec) {
